@@ -2,7 +2,7 @@ package Mojolicious::Plugin::ConfigSimple;
 use Mojo::Base 'Mojolicious::Plugin';
 use Config::Simple::Extended;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub register {
   my ($self, $app, $args) = @_;
@@ -26,7 +26,7 @@ sub register {
   } else {
     die "Constructor invoked with no Confirguration File, see perldoc for details."
   }
-  return $cfg;
+  return wantarray ? ( \%{$cfg->vars}, $cfg ) : \%{$cfg->vars};
 }
 
 sub version {
@@ -49,7 +49,7 @@ Mojolicious::Plugin::ConfigSimple - Config::Simple::Extended
 
 =head1 VERSION 
 
-Version 0.02
+Version 0.03
 
 my $version = &Mojolicious::Plugin::ConfigSimple::version;
 will return the currently installed version numbers for the 
@@ -59,10 +59,10 @@ key dependent modules.
 
   # Mojolicious
   my $ini = '/etc/myapp/config.ini';
-  my $cfg = $self->plugin('ConfigSimple' => { config_files => [ $ini ] } );
+  my ($config, $cfg) = $self->plugin('ConfigSimple' => { config_files => [ $ini ] } );
 
   # Mojolicious::Lite
-  my $cfg = $plugin 'ConfigSimple' => { config_file => $ini };
+  my ($config, $cfg) = $plugin 'ConfigSimple' => { config_file => $ini };
 
 =head1 DESCRIPTION
 
@@ -71,7 +71,11 @@ It is a very simple wrapper around L<Config::Simple::Extended>,
 which in turn wraps L<Config::Simple>.  Those two modules fully 
 document their uses and interfaces and you are encouraged to 
 review their perldoc to learn more.  But a quick summary is 
-available below.  
+available below.  If you prefer the more idiomatic Mojo tradition 
+of an $app->config->{'data_structure'} to the object oriented 
+interface provided by the returned $cfg object, say for instance 
+to support hypnotoad, then by all means.  The non-object data 
+structure is returned if invoked in scalar context.
 
 =head1 METHODS
 
@@ -100,7 +104,11 @@ Try these:
 
     my $debug = $cfg->param("default.debug");
     my $db_connection_credentials = $cfg->get_block( 'db' );
-    my %cfg = $cfg-vars;
+    my %cfg = $cfg->vars;
+
+If this plugin is registered in scalar context, it returns
+\%{$cfg->vars}, providing the data structure traditionally 
+provided by $app->config in a Mojolicious environment.  
 
 =head1 SEE ALSO
 
